@@ -42,16 +42,42 @@ DFXP_DEFAULT_STYLE = {
 
 DFXP_DEFAULT_REGION = Layout(
     alignment=Alignment(
-        HorizontalAlignmentEnum.CENTER, VerticalAlignmentEnum.BOTTOM)
+        HorizontalAlignmentEnum.START, VerticalAlignmentEnum.BOTTOM)
 )
 
 DFXP_DEFAULT_STYLE_ID = 'default'
 DFXP_DEFAULT_REGION_ID = 'bottom'
 
+CLOCK_TIME_PATTERN = (
+    r'(?P<clock_time>(?P<hours>\d+):(?P<minutes>\d{2}):(?P<seconds>\d{2})'
+    r'(:(?P<frames>\d{2})|\.(?P<sub_frames>\d+))?)'
+)
+OFFSET_TIME_PATTERN = (r'(?P<offset_time>(?P<time_count>\d+(\.\d+)?)'
+                       r'(?P<metric>h|m|s|ms|f|t))')
+TIME_EXPRESSION_PATTERN = re.compile(
+    fr'^({CLOCK_TIME_PATTERN}|{OFFSET_TIME_PATTERN})$')
+
+MICROSECONDS_PER_UNIT = {
+    "hours": 3600000000,
+    "minutes": 60000000,
+    "seconds": 1000000,
+    "milliseconds": 1000
+}
+
+DFXP_DEFAULT_LANGUAGE_CODE = "en"
+
 
 class DFXPReader(BaseReader):
     def __init__(self, *args, **kw):
         super().__init__(*args, **kw)
+        """ This is to support positioning attributes directly on the paragraph
+        elements. According to the documentation, these attributes shouldn't be
+        taken into account:
+        https://www.w3.org/TR/ttml1/#style-attribute-origin
+        This attribute (origin, extent) may be specified by any element type 
+        that permits use of attributes in the TT Style Namespace; however,
+        this attribute applies as a style property only to those element types
+        indicated in the following table."""
         self.read_invalid_positioning = (
             kw.get('read_invalid_positioning', False))
         self.nodes = []
@@ -67,7 +93,8 @@ class DFXPReader(BaseReader):
             raise InvalidInputError('The content is not a unicode string.')
 
         dfxp_document = self._get_dfxp_parser_class()(
-            content, read_invalid_positioning=self.read_invalid_positioning)
+            content, read_invalid_positioning=
+            self.read_invalid_positioning)
 
         caption_dict = {}
         style_dict = {}
@@ -79,7 +106,7 @@ class DFXPReader(BaseReader):
         for div in dfxp_document.find_all('div'):
             lang = div.attrs.get('xml:lang', default_language)
 
-            caption_dict[lang] = self._translate_div(div)
+            caption_dict[lang] = self._convert_div_to_caption_list(div)
 
         for style in dfxp_document.find_all('style'):
             id_ = style.attrs.get('xml:id') or style.attrs.get('id')
@@ -88,7 +115,7 @@ class DFXPReader(BaseReader):
                 # descendants of <region> tags. See link:
                 # http://www.w3.org/TR/ttaf1-dfxp/#styling-vocabulary-style
                 if 'region' not in [parent_.name for parent_ in style.parents]:
-                    style_dict[id_] = self._translate_style(style)
+                    style_dict[id_] = self._convert_style(style)
 
         caption_set = CaptionSet(caption_dict, styles=style_dict)
 
@@ -102,18 +129,18 @@ class DFXPReader(BaseReader):
         """Hook method for providing a custom DFXP parser"""
         return LayoutAwareDFXPParser
 
-    def _translate_div(self, div):
+    def _convert_div_to_caption_list(self, div):
         return CaptionList(
-            [self._translate_p_tag(p_tag)
+            [self._convert_p_tag_to_caption(p_tag)
              for p_tag in div.find_all('p') if p_tag.get_text().strip()],
             div.layout_info
         )
 
-    def _translate_p_tag(self, p_tag):
-        start, end = self._find_times(p_tag)
+    def _convert_p_tag_to_caption(self, p_tag):
+        start, end = self._find_and_convert_times(p_tag)
         self.nodes = []
-        self._translate_tag(p_tag)
-        styles = self._translate_style(p_tag)
+        self._convert_tag_to_node(p_tag)
+        styles = self._convert_style(p_tag)
 
         if len(self.nodes) > 0:
             return Caption(
@@ -121,7 +148,7 @@ class DFXPReader(BaseReader):
                 layout_info=p_tag.layout_info)
         return None
 
-    def _find_times(self, p_tag):
+    def _find_and_convert_times(self, p_tag):
         begin = p_tag.get('begin')
         if not begin:
             raise CaptionReadTimingError(
@@ -133,63 +160,62 @@ class DFXPReader(BaseReader):
             raise CaptionReadTimingError(
                 f'Missing end time or duration on line {p_tag}.')
 
-        start = self._translate_time(begin)
+        start = self._convert_timestamp_to_microseconds(begin)
         if end:
-            end = self._translate_time(p_tag['end'])
+            end = self._convert_timestamp_to_microseconds(p_tag['end'])
         else:
-            dur = self._translate_time(p_tag['dur'])
+            dur = self._convert_timestamp_to_microseconds(p_tag['dur'])
             end = start + dur
 
         return start, end
 
-    def _translate_time(self, stamp):
-        if stamp[-1].isdigit():
-            timesplit = stamp.split(':')
-
-            if len(timesplit) < 3:
-                raise CaptionReadSyntaxError(
-                    'Begin and end time should follow the '
-                    'hour:minute:seconds.milliseconds or '
-                    'hour:minute:seconds:frames format. '
-                    'Milliseconds and frames are optional.'
-                    f'Please correct the following time {stamp}')
-
-            if '.' not in timesplit[2]:
-                timesplit[2] += '.000'
-
-            secsplit = timesplit[2].split('.')
-            if len(timesplit) > 3:
-                secsplit.append(float(timesplit[3]) / 30 * 1000000)
-            while len(secsplit[1]) < 3:
-                secsplit[1] += '0'
-            microseconds = (int(timesplit[0]) * 3600000000
-                            + int(timesplit[1]) * 60000000
-                            + int(secsplit[0]) * 1000000
-                            + int(secsplit[1]) * 1000)
-            if len(secsplit) > 2:
-                microseconds += int(secsplit[2])
-
-            return microseconds
+    def _convert_timestamp_to_microseconds(self, stamp):
+        match = TIME_EXPRESSION_PATTERN.search(stamp)
+        if not match:
+            raise CaptionReadTimingError(
+                f'Invalid timestamp: {stamp}. Accepted formats: hh:mm:ss / '
+                'hh:mm:ss:ff / hh:mm:ss.sub-frames / time_count h|m|s|ms|f.')
+        if match.group('clock_time'):
+            return self._convert_clock_time_to_microseconds(match)
         else:
-            # Must be offset-time
-            m = re.search('^([0-9.]+)([a-z]+)$', stamp)
-            value = float(m.group(1))
-            metric = m.group(2)
-            if metric == "h":
-                microseconds = value * 60 * 60 * 1000000
-            elif metric == "m":
-                microseconds = value * 60 * 1000000
-            elif metric == "s":
-                microseconds = value * 1000000
-            elif metric == "ms":
-                microseconds = value * 1000
-            else:
-                raise InvalidInputError("Unsupported offset-time metric "
-                                        + metric)
+            return self._convert_time_count_to_microseconds(match)
 
-            return int(microseconds)
+    @staticmethod
+    def _convert_clock_time_to_microseconds(clock_time_match):
+        microseconds = int(clock_time_match.group('hours')) * \
+                       MICROSECONDS_PER_UNIT["hours"]
+        microseconds += int(clock_time_match.group('minutes')) * \
+                        MICROSECONDS_PER_UNIT["minutes"]
+        microseconds += int(clock_time_match.group('seconds')) * \
+                        MICROSECONDS_PER_UNIT["seconds"]
+        if clock_time_match.group('sub_frames'):
+            microseconds += int(clock_time_match.group('sub_frames').ljust(
+                3, '0')) * MICROSECONDS_PER_UNIT["milliseconds"]
+        elif clock_time_match.group('frames'):
+            microseconds += int(clock_time_match.group('frames')) / 30 * \
+                            MICROSECONDS_PER_UNIT["seconds"]
+        return int(microseconds)
 
-    def _translate_tag(self, tag):
+    @staticmethod
+    def _convert_time_count_to_microseconds(time_count_match):
+        value = float(time_count_match.group('time_count'))
+        metric = time_count_match.group("metric")
+        if metric == "h":
+            microseconds = value * MICROSECONDS_PER_UNIT["hours"]
+        elif metric == "m":
+            microseconds = value * MICROSECONDS_PER_UNIT["minutes"]
+        elif metric == "s":
+            microseconds = value * MICROSECONDS_PER_UNIT["seconds"]
+        elif metric == "ms":
+            microseconds = value * MICROSECONDS_PER_UNIT["milliseconds"]
+        elif metric == "f":
+            microseconds = value / 30 * MICROSECONDS_PER_UNIT["seconds"]
+        elif metric == "t":
+            raise NotImplementedError("The tick metric for time count is "
+                                      "not currently implemented.")
+        return int(microseconds)
+
+    def _convert_tag_to_node(self, tag):
         # convert text
         if isinstance(tag, NavigableString):
             # strips indentation whitespace only
@@ -212,15 +238,15 @@ class DFXPReader(BaseReader):
         # convert italics
         elif tag.name == 'span':
             # convert span
-            self._translate_span(tag)
+            self._convert_span_to_nodes(tag)
         else:
             # recursively call function for any children elements
             for a in tag.contents:
-                self._translate_tag(a)
+                self._convert_tag_to_node(a)
 
-    def _translate_span(self, tag):
+    def _convert_span_to_nodes(self, tag):
         # convert tag attributes
-        args = self._translate_style(tag)
+        args = self._convert_style(tag)
         # only include span tag if attributes returned
         # TODO - this is an obvious very old bug. args will be a dictionary.
         # but since nobody complained, I'll leave it like that.
@@ -234,7 +260,7 @@ class DFXPReader(BaseReader):
 
             # recursively call function for any children elements
             for a in tag.contents:
-                self._translate_tag(a)
+                self._convert_tag_to_node(a)
             node = CaptionNode.create_style(
                 False, args, layout_info=tag.layout_info)
             node.start = False
@@ -242,10 +268,10 @@ class DFXPReader(BaseReader):
             self.nodes.append(node)
         else:
             for a in tag.contents:
-                self._translate_tag(a)
+                self._convert_tag_to_node(a)
 
     # convert style from DFXP
-    def _translate_style(self, tag):
+    def _convert_style(self, tag):
         """Converts the attributes of an XML node to a dictionary. This is a
          deprecated method of handling styling/ layout information, and
          overlaps (in partially known ways)with the newer way of doing stuff.
@@ -296,19 +322,19 @@ class DFXPWriter(BaseWriter):
         """Converts a CaptionSet into an equivalent corresponding DFXP file
 
         :type caption_set: pycaption.base.CaptionSet
-        :param force: only use this language, if available in the caption_set
+        :param force: only use this language, if available in the
+        caption_set
 
         :rtype: str
         """
         dfxp = BeautifulSoup(DFXP_BASE_MARKUP, 'lxml-xml')
-        dfxp.find('tt')['xml:lang'] = "en"
 
         langs = caption_set.get_languages()
         if force in langs:
             langs = [force]
             dfxp.find('tt')['xml:lang'] = force
         else:
-            dfxp.find('tt')['xml:lang'] = "en"
+            dfxp.find('tt')['xml:lang'] = DFXP_DEFAULT_LANGUAGE_CODE
 
         caption_set = deepcopy(caption_set)
 
@@ -520,8 +546,8 @@ class LayoutAwareDFXPParser(BeautifulSoup):
         dependency and (2) BeautifulSoup says it's the slowest option.
 
         :type read_invalid_positioning: bool
-        :param read_invalid_positioning: if True, will try to also look for
-            layout info on every element itself (even if the docs explicitly
+        :param read_invalid_positioning: if True, will try to also look
+            for layout info on every element itself (even if the docs explicitly
             call for ignoring attributes, when incorrectly placed)
 
 
@@ -673,6 +699,7 @@ class LayoutInfoScraper:
     """Encapsulates the methods for determining the layout information about
     an element (with the element's region playing an important role).
     """
+
     def __init__(self, document, region=None):
         """
         :param document: the BeautifulSoup document instance, of which `region`
@@ -824,16 +851,16 @@ class LayoutInfoScraper:
             text_align_source = None
 
         text_align = (
-            self._find_attribute(text_align_source, 'tts:textAlign')
-            or _create_external_horizontal_alignment(
-                DFXP_DEFAULT_REGION.alignment.horizontal
-            )
+                self._find_attribute(text_align_source, 'tts:textAlign')
+                or _create_external_horizontal_alignment(
+            DFXP_DEFAULT_REGION.alignment.horizontal
+        )
         )
         display_align = (
-            self._find_attribute(usable_elem, 'tts:displayAlign')
-            or _create_external_vertical_alignment(
-                DFXP_DEFAULT_REGION.alignment.vertical
-            )
+                self._find_attribute(usable_elem, 'tts:displayAlign')
+                or _create_external_vertical_alignment(
+            DFXP_DEFAULT_REGION.alignment.vertical
+        )
         )
         alignment = _create_internal_alignment(text_align, display_align)
 
@@ -958,6 +985,7 @@ class RegionCreator:
 
         *: NULL means LayoutAwareBeautifulParser.NO_POSITIONING_INFO
     """
+
     def __init__(self, dfxp, caption_set):
         """
         :type dfxp: BeautifulSoup
@@ -1025,7 +1053,6 @@ class RegionCreator:
             if (
                     region_spec.origin or region_spec.extent
                     or region_spec.padding or region_spec.alignment):
-
                 new_region = dfxp.new_tag('region')
                 new_id = id_factory()
                 new_region['xml:id'] = new_id
@@ -1299,10 +1326,7 @@ def _convert_layout_to_attributes(layout):
     """
     result = {}
     if not layout:
-        # TODO - change this to actually use the DFXP_DEFAULT_REGION
-        result['tts:textAlign'] = HorizontalAlignmentEnum.CENTER
-        result['tts:displayAlign'] = VerticalAlignmentEnum.BOTTOM
-        return result
+        return _create_external_alignment(DFXP_DEFAULT_REGION.alignment)
 
     if layout.origin:
         result['tts:origin'] = layout.origin.to_xml_attribute()
@@ -1315,6 +1339,8 @@ def _convert_layout_to_attributes(layout):
 
     if layout.alignment:
         result.update(_create_external_alignment(layout.alignment))
+    else:
+        result.update(_create_external_alignment(DFXP_DEFAULT_REGION.alignment))
 
     return result
 
@@ -1323,6 +1349,7 @@ class _OrderedSet(list):
     """Quick implementation of a set that tracks the order. If this is a
     performance bottleneck, replace it with some other implementation.
     """
+
     def add(self, p_object):
         if p_object not in self:
             super().append(p_object)
